package cn.iocoder.yudao.module.system.service.hr;

import cn.iocoder.yudao.framework.common.enums.CommonStatusEnum;
import cn.iocoder.yudao.module.system.dal.dataobject.hr.SalaryTypeDO;
import cn.iocoder.yudao.module.system.dal.mysql.hr.SalaryTypeMapper;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.List;

import static cn.iocoder.yudao.framework.common.exception.util.ServiceExceptionUtil.exception;
import static cn.iocoder.yudao.module.system.enums.ErrorCodeConstants.*;

@Service
public class SalaryTypeServiceImpl implements SalaryTypeService{

    @Resource
    private SalaryTypeMapper salaryTypeMapper;

    @Override
    public Long createSalaryType(String name) {

        // 校验类型名称唯一性
        if (salaryTypeMapper.selectCount(SalaryTypeDO::getName, name) > 0L) {
            throw exception(SALARY_TYPE_NAME_EXISTS);
        }

        SalaryTypeDO salaryTypeDO = new SalaryTypeDO()
                .setName(name)
                .setStatus(CommonStatusEnum.ENABLE.getStatus());

        salaryTypeMapper.insert(salaryTypeDO);
        return salaryTypeDO.getId();
    }

    @Override
    public void updateSalaryType(Long id, String name) {

        validateTypeExists(id);

        SalaryTypeDO salaryTypeDO = new SalaryTypeDO()
                .setId(id)
                .setName(name);

        salaryTypeMapper.updateById(salaryTypeDO);
    }

    @Override
    public void updateSalaryTypeStatus(Long id, Integer status) {

        validateTypeExists(id);

        SalaryTypeDO salaryTypeDO = new SalaryTypeDO()
                .setId(id)
                .setStatus(status);

        // 同步设置 类型配置状态

        salaryTypeMapper.updateById(salaryTypeDO);
    }

    private void validateTypeExists(Long id) {
        if (salaryTypeMapper.selectById(id) == null) {
            throw exception(SALARY_TYPE_NOT_EXISTS);
        }
    }

    @Override
    public SalaryTypeDO getSalaryType(Long id) {
        return salaryTypeMapper.selectById(id);
    }

    @Override
    public List<SalaryTypeDO> getSalaryTypeList() {
        return salaryTypeMapper.selectList();
    }
}
